==> ejc-bfyjerp-api-3.0.0-20250224.080835-144-sources.jar: com/ejianc/business/finance/vo/DaypayVO.java <==
package com.ejianc.business.finance.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 出纳资金-出纳日报表-主表
 * 
 * @author generator
 * 
 */
public class DaypayVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date date; // 日期
    private BigDecimal startMny; // 期初金额
    private BigDecimal endMny; // 结余金额
    private BigDecimal incomeMoney; // 收入
    private BigDecimal payMoney; // 支出
    private List<DaypayDetailVO> daypayDetailList = new ArrayList<>(); // 出纳资金-占用资金表-子表

    public BigDecimal getIncomeMoney() {
        return incomeMoney;
    }

    public void setIncomeMoney(BigDecimal incomeMoney) {
        this.incomeMoney = incomeMoney;
    }

    public BigDecimal getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(BigDecimal payMoney) {
        this.payMoney = payMoney;
    }

    public List<DaypayDetailVO> getDaypayDetailList() {
        return daypayDetailList;
    }

    public void setDaypayDetailList(List<DaypayDetailVO> daypayDetailList) {
        this.daypayDetailList = daypayDetailList;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public BigDecimal getStartMny() {
        return startMny;
    }

    public void setStartMny(BigDecimal startMny) {
        this.startMny = startMny;
    }
    public BigDecimal getEndMny() {
        return endMny;
    }

    public void setEndMny(BigDecimal endMny) {
        this.endMny = endMny;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250929.071746-299-sources.jar: com/ejianc/business/finance/vo/DaypayVO.java <==
package com.ejianc.business.finance.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 出纳资金-出纳日报表-主表
 * 
 * @author generator
 * 
 */
public class DaypayVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date date; // 日期
    private BigDecimal startMny; // 期初金额
    private BigDecimal endMny; // 结余金额
    private BigDecimal incomeMoney; // 收入
    private BigDecimal payMoney; // 支出
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date lastDate; // 上次统计日期
    private String dateStr; // 统计期限
    private String billStateName;
    private List<DaypayDetailVO> daypayDetailList = new ArrayList<>(); // 出纳资金-占用资金表-子表

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Date getLastDate() {
        return lastDate;
    }

    public void setLastDate(Date lastDate) {
        this.lastDate = lastDate;
    }

    public String getDateStr() {
        return dateStr;
    }

    public void setDateStr(String dateStr) {
        this.dateStr = dateStr;
    }

    public BigDecimal getIncomeMoney() {
        return incomeMoney;
    }

    public void setIncomeMoney(BigDecimal incomeMoney) {
        this.incomeMoney = incomeMoney;
    }

    public BigDecimal getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(BigDecimal payMoney) {
        this.payMoney = payMoney;
    }

    public List<DaypayDetailVO> getDaypayDetailList() {
        return daypayDetailList;
    }

    public void setDaypayDetailList(List<DaypayDetailVO> daypayDetailList) {
        this.daypayDetailList = daypayDetailList;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public BigDecimal getStartMny() {
        return startMny;
    }

    public void setStartMny(BigDecimal startMny) {
        this.startMny = startMny;
    }
    public BigDecimal getEndMny() {
        return endMny;
    }

    public void setEndMny(BigDecimal endMny) {
        this.endMny = endMny;
    }

}
